package com.yanzuoguang.mq.dao.impl;

import com.yanzuoguang.dao.DaoConst;
import com.yanzuoguang.dao.impl.BaseDaoImpl;
import com.yanzuoguang.dao.impl.TableFieldString;
import com.yanzuoguang.mq.dao.QueueDao;
import com.yanzuoguang.mq.vo.QueueVo;
import com.yanzuoguang.mq.vo.req.QueueQueryReqVo;
import com.yanzuoguang.util.vo.PageSizeData;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
public class QueueDaoImpl extends BaseDaoImpl implements QueueDao {

    private static final String SAVE_WITH_SQL = "SAVE_WITH_SQL";

    /**
     * 注册SQL语句
     */
    @Override
    protected void init() {
        // 根据实体生成增删改查语句
        register(QueueVo.class);

        table.addSaveWith(SAVE_WITH_SQL, new TableFieldString("queueName", "exchangeName", "routeKey"));

        table.add(DaoConst.QUERY, "SELECT * FROM Queue_Queue WHERE 1=1 ")
                .add("queueName", "AND ( QueueName LIKE CONCAT('%',?,'%') OR DelayQueueName LIKE CONCAT('%',?,'%') )")
                .add("exchangeName", "AND ( ExchangeName LIKE CONCAT('%',?,'%') OR DelayExchangeName LIKE CONCAT('%',?,'%') )")
                .add("routeKey", "AND ( RouteKey LIKE CONCAT('%',?,'%') OR DelayRouteKey LIKE CONCAT('%',?,'%') )")
                .add("delay", "AND ( DelayTime > 0 OR DelayExchangeName > '' OR DelayQueueName > '' OR DelayRouteKey > '' )")
        ;
    }

    /**
     * 保存队列
     *
     * @param req
     * @return
     */
    @Override
    public String saveWith(QueueVo req) {
        return this.saveWith(QueueVo.class, SAVE_WITH_SQL, req);
    }

    /**
     * 查询现有消息队列
     *
     * @param req
     * @return
     */
    @Override
    public PageSizeData<QueueVo> query(QueueQueryReqVo req) {
        return this.queryPage(QueueVo.class, req, DaoConst.QUERY, req);
    }

    /**
     * 获取所有的队列
     *
     * @return 队列列表
     */
    @Override
    public List<QueueVo> list() {
        return this.query(QueueVo.class, DaoConst.QUERY, null);
    }
}
